Class: Thunder::Boolean
- Inherits:
-
Object
- Object
- Thunder::Boolean
- Defined in:
- lib/thunder.rb
Overview
Used to indicate a boolean true or false value for options processing
Used to indicate a boolean true or false value for options processing